@@ -3,11 +3,10 @@ use strict;
 use warnings;
 
 package JSON::Path;
-$JSON::Path::VERSION = '0.5';
+$JSON::Path::VERSION = '0.51';
 # VERSION
 
-use Exporter::Tiny ();
-our @ISA       = qw/ Exporter::Tiny /;
+use Exporter::Shiny qw/ jpath jpath1 jpath_map /;
 our $AUTHORITY = 'cpan:POPEFELIX';
 our $Safe      = 1;
 
@@ -17,8 +16,6 @@ use JSON::Path::Evaluator;
 use Scalar::Util qw[blessed];
 use LV ();
 
-our @EXPORT_OK = qw/ jpath jpath1 jpath_map /;
-
 use overload '""' => \&to_string;
 
 sub jpath {
@@ -138,7 +135,7 @@ JSON::Path
 
 =head1 VERSION
 
-version 0.5
+version 0.51
 
 =head1 SYNOPSIS
 
@@ -424,7 +421,7 @@ Kit Peters <popefelix@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Kit Peters.
+This software is copyright (c) 2022 by Kit Peters.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
