@@ -1,5 +1,5 @@
 package JSON::Path::Evaluator;
-$JSON::Path::Evaluator::VERSION = '0.5';
+$JSON::Path::Evaluator::VERSION = '0.51';
 use strict;
 use warnings;
 use 5.008;
@@ -8,7 +8,6 @@ use 5.008;
 
 use Carp;
 use Carp::Assert qw(assert);
-use Exporter::Tiny ();
 use JSON::MaybeXS;
 use JSON::Path::Constants qw(:operators :symbols);
 use JSON::Path::Tokenizer qw(tokenize);
@@ -17,13 +16,11 @@ use Readonly;
 use Safe;
 use Scalar::Util qw/looks_like_number blessed refaddr/;
 use Storable qw/dclone/;
-use Sys::Hostname qw/hostname/;
 use Try::Tiny;
 
 # VERSION
-use base q(Exporter);
+use Exporter::Shiny qw/evaluate_jsonpath/;
 our $AUTHORITY = 'cpan:POPEFELIX';
-our @EXPORT_OK = qw/ evaluate_jsonpath /;
 
 Readonly my $OPERATOR_IS_TRUE         => 'IS_TRUE';
 Readonly my $OPERATOR_TYPE_PATH       => 1;
@@ -657,7 +654,7 @@ JSON::Path::Evaluator - A module that recursively evaluates JSONPath expressions
 
 =head1 VERSION
 
-version 0.5
+version 0.51
 
 =head1 SYNOPSIS
 
@@ -925,7 +922,7 @@ Kit Peters <popefelix@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Kit Peters.
+This software is copyright (c) 2022 by Kit Peters.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
